# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/bidding_strategy_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import bidding_strategy_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_bidding__strategy__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/bidding_strategy_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nEgoogle/ads/googleads_v0/proto/services/bidding_strategy_service.proto\x12 google.ads.googleads.v0.services\x1a>google/ads/googleads_v0/proto/resources/bidding_strategy.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"2\n\x19GetBiddingStrategyRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x85\x01\n\x1eMutateBiddingStrategiesRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12N\n\noperations\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v0.services.BiddingStrategyOperation\"\xf6\x01\n\x18\x42iddingStrategyOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x44\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x32.google.ads.googleads.v0.resources.BiddingStrategyH\x00\x12\x44\n\x06update\x18\x02 \x01(\x0b\x32\x32.google.ads.googleads.v0.resources.BiddingStrategyH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"q\n\x1fMutateBiddingStrategiesResponse\x12N\n\x07results\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v0.services.MutateBiddingStrategyResult\"4\n\x1bMutateBiddingStrategyResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xc1\x03\n\x16\x42iddingStrategyService\x12\xc2\x01\n\x12GetBiddingStrategy\x12;.google.ads.googleads.v0.services.GetBiddingStrategyRequest\x1a\x32.google.ads.googleads.v0.resources.BiddingStrategy\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v0/{resource_name=customers/*/biddingStrategies/*}\x12\xe1\x01\n\x17MutateBiddingStrategies\x12@.google.ads.googleads.v0.services.MutateBiddingStrategiesRequest\x1a\x41.google.ads.googleads.v0.services.MutateBiddingStrategiesResponse\"A\x82\xd3\xe4\x93\x02;\"6/v0/customers/{customer_id=*}/biddingStrategies:mutate:\x01*B\xdb\x01\n$com.google.ads.googleads.v0.servicesB\x1b\x42iddingStrategyServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_bidding__strategy__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETBIDDINGSTRATEGYREQUEST = _descriptor.Descriptor(
  name='GetBiddingStrategyRequest',
  full_name='google.ads.googleads.v0.services.GetBiddingStrategyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetBiddingStrategyRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=285,
)


_MUTATEBIDDINGSTRATEGIESREQUEST = _descriptor.Descriptor(
  name='MutateBiddingStrategiesRequest',
  full_name='google.ads.googleads.v0.services.MutateBiddingStrategiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateBiddingStrategiesRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateBiddingStrategiesRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=421,
)


_BIDDINGSTRATEGYOPERATION = _descriptor.Descriptor(
  name='BiddingStrategyOperation',
  full_name='google.ads.googleads.v0.services.BiddingStrategyOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.BiddingStrategyOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.BiddingStrategyOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.BiddingStrategyOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.BiddingStrategyOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.BiddingStrategyOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=424,
  serialized_end=670,
)


_MUTATEBIDDINGSTRATEGIESRESPONSE = _descriptor.Descriptor(
  name='MutateBiddingStrategiesResponse',
  full_name='google.ads.googleads.v0.services.MutateBiddingStrategiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateBiddingStrategiesResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=785,
)


_MUTATEBIDDINGSTRATEGYRESULT = _descriptor.Descriptor(
  name='MutateBiddingStrategyResult',
  full_name='google.ads.googleads.v0.services.MutateBiddingStrategyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateBiddingStrategyResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=839,
)

_MUTATEBIDDINGSTRATEGIESREQUEST.fields_by_name['operations'].message_type = _BIDDINGSTRATEGYOPERATION
_BIDDINGSTRATEGYOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_BIDDINGSTRATEGYOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_bidding__strategy__pb2._BIDDINGSTRATEGY
_BIDDINGSTRATEGYOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_bidding__strategy__pb2._BIDDINGSTRATEGY
_BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation'].fields.append(
  _BIDDINGSTRATEGYOPERATION.fields_by_name['create'])
_BIDDINGSTRATEGYOPERATION.fields_by_name['create'].containing_oneof = _BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation']
_BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation'].fields.append(
  _BIDDINGSTRATEGYOPERATION.fields_by_name['update'])
_BIDDINGSTRATEGYOPERATION.fields_by_name['update'].containing_oneof = _BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation']
_BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation'].fields.append(
  _BIDDINGSTRATEGYOPERATION.fields_by_name['remove'])
_BIDDINGSTRATEGYOPERATION.fields_by_name['remove'].containing_oneof = _BIDDINGSTRATEGYOPERATION.oneofs_by_name['operation']
_MUTATEBIDDINGSTRATEGIESRESPONSE.fields_by_name['results'].message_type = _MUTATEBIDDINGSTRATEGYRESULT
DESCRIPTOR.message_types_by_name['GetBiddingStrategyRequest'] = _GETBIDDINGSTRATEGYREQUEST
DESCRIPTOR.message_types_by_name['MutateBiddingStrategiesRequest'] = _MUTATEBIDDINGSTRATEGIESREQUEST
DESCRIPTOR.message_types_by_name['BiddingStrategyOperation'] = _BIDDINGSTRATEGYOPERATION
DESCRIPTOR.message_types_by_name['MutateBiddingStrategiesResponse'] = _MUTATEBIDDINGSTRATEGIESRESPONSE
DESCRIPTOR.message_types_by_name['MutateBiddingStrategyResult'] = _MUTATEBIDDINGSTRATEGYRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBiddingStrategyRequest = _reflection.GeneratedProtocolMessageType('GetBiddingStrategyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBIDDINGSTRATEGYREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.bidding_strategy_service_pb2'
  ,
  __doc__ = """Request message for
  [BiddingStrategyService.GetBiddingStrategy][google.ads.googleads.v0.services.BiddingStrategyService.GetBiddingStrategy].
  
  
  Attributes:
      resource_name:
          The resource name of the bidding strategy to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetBiddingStrategyRequest)
  ))
_sym_db.RegisterMessage(GetBiddingStrategyRequest)

MutateBiddingStrategiesRequest = _reflection.GeneratedProtocolMessageType('MutateBiddingStrategiesRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBIDDINGSTRATEGIESREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.bidding_strategy_service_pb2'
  ,
  __doc__ = """Request message for
  [BiddingStrategyService.MutateBiddingStrategies][google.ads.googleads.v0.services.BiddingStrategyService.MutateBiddingStrategies].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose bidding strategies are being
          modified.
      operations:
          The list of operations to perform on individual bidding
          strategies.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateBiddingStrategiesRequest)
  ))
_sym_db.RegisterMessage(MutateBiddingStrategiesRequest)

BiddingStrategyOperation = _reflection.GeneratedProtocolMessageType('BiddingStrategyOperation', (_message.Message,), dict(
  DESCRIPTOR = _BIDDINGSTRATEGYOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.bidding_strategy_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a bidding strategy.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          bidding strategy.
      update:
          Update operation: The bidding strategy is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed bidding
          strategy is expected, in this format:  ``customers/{customer_i
          d}/biddingStrategies/{bidding_strategy_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.BiddingStrategyOperation)
  ))
_sym_db.RegisterMessage(BiddingStrategyOperation)

MutateBiddingStrategiesResponse = _reflection.GeneratedProtocolMessageType('MutateBiddingStrategiesResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBIDDINGSTRATEGIESRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.bidding_strategy_service_pb2'
  ,
  __doc__ = """Response message for bidding strategy mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateBiddingStrategiesResponse)
  ))
_sym_db.RegisterMessage(MutateBiddingStrategiesResponse)

MutateBiddingStrategyResult = _reflection.GeneratedProtocolMessageType('MutateBiddingStrategyResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBIDDINGSTRATEGYRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.bidding_strategy_service_pb2'
  ,
  __doc__ = """The result for the bidding strategy mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateBiddingStrategyResult)
  ))
_sym_db.RegisterMessage(MutateBiddingStrategyResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\033BiddingStrategyServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_BIDDINGSTRATEGYSERVICE = _descriptor.ServiceDescriptor(
  name='BiddingStrategyService',
  full_name='google.ads.googleads.v0.services.BiddingStrategyService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=842,
  serialized_end=1291,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetBiddingStrategy',
    full_name='google.ads.googleads.v0.services.BiddingStrategyService.GetBiddingStrategy',
    index=0,
    containing_service=None,
    input_type=_GETBIDDINGSTRATEGYREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_bidding__strategy__pb2._BIDDINGSTRATEGY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0025\0223/v0/{resource_name=customers/*/biddingStrategies/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateBiddingStrategies',
    full_name='google.ads.googleads.v0.services.BiddingStrategyService.MutateBiddingStrategies',
    index=1,
    containing_service=None,
    input_type=_MUTATEBIDDINGSTRATEGIESREQUEST,
    output_type=_MUTATEBIDDINGSTRATEGIESRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002;\"6/v0/customers/{customer_id=*}/biddingStrategies:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_BIDDINGSTRATEGYSERVICE)

DESCRIPTOR.services_by_name['BiddingStrategyService'] = _BIDDINGSTRATEGYSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/keyword_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/keyword_view.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n:google/ads/googleads_v0/proto/resources/keyword_view.proto\x12!google.ads.googleads.v0.resources\"$\n\x0bKeywordView\x12\x15\n\rresource_name\x18\x01 \x01(\tB\xd5\x01\n%com.google.ads.googleads.v0.resourcesB\x10KeywordViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
)




_KEYWORDVIEW = _descriptor.Descriptor(
  name='KeywordView',
  full_name='google.ads.googleads.v0.resources.KeywordView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.KeywordView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=133,
)

DESCRIPTOR.message_types_by_name['KeywordView'] = _KEYWORDVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordView = _reflection.GeneratedProtocolMessageType('KeywordView', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDVIEW,
  __module__ = 'google.ads.google_ads.v0.proto.resources.keyword_view_pb2'
  ,
  __doc__ = """A keyword view.
  
  
  Attributes:
      resource_name:
          The resource name of the keyword view. Keyword view resource
          names have the form:  ``customers/{customer_id}/keywordViews/{
          ad_group_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.KeywordView)
  ))
_sym_db.RegisterMessage(KeywordView)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\020KeywordViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_bid_modifier_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_bid_modifier_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_bid_modifier_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nJgoogle/ads/googleads_v0/proto/services/campaign_bid_modifier_service.proto\x12 google.ads.googleads.v0.services\x1a\x43google/ads/googleads_v0/proto/resources/campaign_bid_modifier.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"6\n\x1dGetCampaignBidModifierRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8c\x01\n!MutateCampaignBidModifiersRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v0.services.CampaignBidModifierOperation\"\x82\x02\n\x1c\x43\x61mpaignBidModifierOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12H\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x36.google.ads.googleads.v0.resources.CampaignBidModifierH\x00\x12H\n\x06update\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v0.resources.CampaignBidModifierH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"x\n\"MutateCampaignBidModifiersResponse\x12R\n\x07results\x18\x02 \x03(\x0b\x32\x41.google.ads.googleads.v0.services.MutateCampaignBidModifierResult\"8\n\x1fMutateCampaignBidModifierResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xe0\x03\n\x1a\x43\x61mpaignBidModifierService\x12\xd1\x01\n\x16GetCampaignBidModifier\x12?.google.ads.googleads.v0.services.GetCampaignBidModifierRequest\x1a\x36.google.ads.googleads.v0.resources.CampaignBidModifier\">\x82\xd3\xe4\x93\x02\x38\x12\x36/v0/{resource_name=customers/*/campaignBidModifiers/*}\x12\xed\x01\n\x1aMutateCampaignBidModifiers\x12\x43.google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest\x1a\x44.google.ads.googleads.v0.services.MutateCampaignBidModifiersResponse\"D\x82\xd3\xe4\x93\x02>\"9/v0/customers/{customer_id=*}/campaignBidModifiers:mutate:\x01*B\xdf\x01\n$com.google.ads.googleads.v0.servicesB\x1f\x43\x61mpaignBidModifierServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNBIDMODIFIERREQUEST = _descriptor.Descriptor(
  name='GetCampaignBidModifierRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignBidModifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignBidModifierRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=299,
)


_MUTATECAMPAIGNBIDMODIFIERSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignBidModifiersRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=442,
)


_CAMPAIGNBIDMODIFIEROPERATION = _descriptor.Descriptor(
  name='CampaignBidModifierOperation',
  full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignBidModifierOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=445,
  serialized_end=703,
)


_MUTATECAMPAIGNBIDMODIFIERSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignBidModifiersResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignBidModifiersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignBidModifiersResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=825,
)


_MUTATECAMPAIGNBIDMODIFIERRESULT = _descriptor.Descriptor(
  name='MutateCampaignBidModifierResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignBidModifierResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignBidModifierResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=883,
)

_MUTATECAMPAIGNBIDMODIFIERSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNBIDMODIFIEROPERATION
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2._CAMPAIGNBIDMODIFIER
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2._CAMPAIGNBIDMODIFIER
_CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['create'])
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation']
_CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['update'])
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation']
_CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['remove'])
_CAMPAIGNBIDMODIFIEROPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNBIDMODIFIEROPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNBIDMODIFIERSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNBIDMODIFIERRESULT
DESCRIPTOR.message_types_by_name['GetCampaignBidModifierRequest'] = _GETCAMPAIGNBIDMODIFIERREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignBidModifiersRequest'] = _MUTATECAMPAIGNBIDMODIFIERSREQUEST
DESCRIPTOR.message_types_by_name['CampaignBidModifierOperation'] = _CAMPAIGNBIDMODIFIEROPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignBidModifiersResponse'] = _MUTATECAMPAIGNBIDMODIFIERSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignBidModifierResult'] = _MUTATECAMPAIGNBIDMODIFIERRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignBidModifierRequest = _reflection.GeneratedProtocolMessageType('GetCampaignBidModifierRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNBIDMODIFIERREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_bid_modifier_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignBidModifierService.GetCampaignBidModifier][google.ads.googleads.v0.services.CampaignBidModifierService.GetCampaignBidModifier].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign bid modifier to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignBidModifierRequest)
  ))
_sym_db.RegisterMessage(GetCampaignBidModifierRequest)

MutateCampaignBidModifiersRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignBidModifiersRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBIDMODIFIERSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_bid_modifier_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignBidModifierService.MutateCampaignBidModifier][].
  
  
  Attributes:
      customer_id:
          ID of the customer whose campaign bid modifiers are being
          modified.
      operations:
          The list of operations to perform on individual campaign bid
          modifiers.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignBidModifiersRequest)

CampaignBidModifierOperation = _reflection.GeneratedProtocolMessageType('CampaignBidModifierOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBIDMODIFIEROPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_bid_modifier_service_pb2'
  ,
  __doc__ = """A single operation (create, remove, update) on a campaign bid modifier.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign bid modifier.
      update:
          Update operation: The campaign bid modifier is expected to
          have a valid resource name.
      remove:
          Remove operation: A resource name for the removed campaign bid
          modifier is expected, in this format:  ``customers/{customer_i
          d}/CampaignBidModifiers/{campaign_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignBidModifierOperation)
  ))
_sym_db.RegisterMessage(CampaignBidModifierOperation)

MutateCampaignBidModifiersResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignBidModifiersResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBIDMODIFIERSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_bid_modifier_service_pb2'
  ,
  __doc__ = """Response message for campaign bid modifiers mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBidModifiersResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignBidModifiersResponse)

MutateCampaignBidModifierResult = _reflection.GeneratedProtocolMessageType('MutateCampaignBidModifierResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBIDMODIFIERRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_bid_modifier_service_pb2'
  ,
  __doc__ = """The result for the criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBidModifierResult)
  ))
_sym_db.RegisterMessage(MutateCampaignBidModifierResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\037CampaignBidModifierServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNBIDMODIFIERSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignBidModifierService',
  full_name='google.ads.googleads.v0.services.CampaignBidModifierService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=886,
  serialized_end=1366,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignBidModifier',
    full_name='google.ads.googleads.v0.services.CampaignBidModifierService.GetCampaignBidModifier',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNBIDMODIFIERREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2._CAMPAIGNBIDMODIFIER,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0028\0226/v0/{resource_name=customers/*/campaignBidModifiers/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignBidModifiers',
    full_name='google.ads.googleads.v0.services.CampaignBidModifierService.MutateCampaignBidModifiers',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNBIDMODIFIERSREQUEST,
    output_type=_MUTATECAMPAIGNBIDMODIFIERSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002>\"9/v0/customers/{customer_id=*}/campaignBidModifiers:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNBIDMODIFIERSERVICE)

DESCRIPTOR.services_by_name['CampaignBidModifierService'] = _CAMPAIGNBIDMODIFIERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_feed_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_feed_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_feed_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nBgoogle/ads/googleads_v0/proto/services/campaign_feed_service.proto\x12 google.ads.googleads.v0.services\x1a;google/ads/googleads_v0/proto/resources/campaign_feed.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"/\n\x16GetCampaignFeedRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"~\n\x1aMutateCampaignFeedsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12K\n\noperations\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v0.services.CampaignFeedOperation\"\xed\x01\n\x15\x43\x61mpaignFeedOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x41\n\x06\x63reate\x18\x01 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CampaignFeedH\x00\x12\x41\n\x06update\x18\x02 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CampaignFeedH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"j\n\x1bMutateCampaignFeedsResponse\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v0.services.MutateCampaignFeedResult\"1\n\x18MutateCampaignFeedResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xa1\x03\n\x13\x43\x61mpaignFeedService\x12\xb5\x01\n\x0fGetCampaignFeed\x12\x38.google.ads.googleads.v0.services.GetCampaignFeedRequest\x1a/.google.ads.googleads.v0.resources.CampaignFeed\"7\x82\xd3\xe4\x93\x02\x31\x12//v0/{resource_name=customers/*/campaignFeeds/*}\x12\xd1\x01\n\x13MutateCampaignFeeds\x12<.google.ads.googleads.v0.services.MutateCampaignFeedsRequest\x1a=.google.ads.googleads.v0.services.MutateCampaignFeedsResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v0/customers/{customer_id=*}/campaignFeeds:mutate:\x01*B\xd8\x01\n$com.google.ads.googleads.v0.servicesB\x18\x43\x61mpaignFeedServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNFEEDREQUEST = _descriptor.Descriptor(
  name='GetCampaignFeedRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignFeedRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=276,
)


_MUTATECAMPAIGNFEEDSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignFeedsRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=404,
)


_CAMPAIGNFEEDOPERATION = _descriptor.Descriptor(
  name='CampaignFeedOperation',
  full_name='google.ads.googleads.v0.services.CampaignFeedOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=407,
  serialized_end=644,
)


_MUTATECAMPAIGNFEEDSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignFeedsResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=752,
)


_MUTATECAMPAIGNFEEDRESULT = _descriptor.Descriptor(
  name='MutateCampaignFeedResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignFeedResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=803,
)

_MUTATECAMPAIGNFEEDSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNFEEDOPERATION
_CAMPAIGNFEEDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNFEEDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED
_CAMPAIGNFEEDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['create'])
_CAMPAIGNFEEDOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['update'])
_CAMPAIGNFEEDOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['remove'])
_CAMPAIGNFEEDOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNFEEDSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNFEEDRESULT
DESCRIPTOR.message_types_by_name['GetCampaignFeedRequest'] = _GETCAMPAIGNFEEDREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignFeedsRequest'] = _MUTATECAMPAIGNFEEDSREQUEST
DESCRIPTOR.message_types_by_name['CampaignFeedOperation'] = _CAMPAIGNFEEDOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignFeedsResponse'] = _MUTATECAMPAIGNFEEDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignFeedResult'] = _MUTATECAMPAIGNFEEDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignFeedRequest = _reflection.GeneratedProtocolMessageType('GetCampaignFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNFEEDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignFeedService.GetCampaignFeed][google.ads.googleads.v0.services.CampaignFeedService.GetCampaignFeed].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign feed to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignFeedRequest)
  ))
_sym_db.RegisterMessage(GetCampaignFeedRequest)

MutateCampaignFeedsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignFeedService.MutateCampaignFeeds][google.ads.googleads.v0.services.CampaignFeedService.MutateCampaignFeeds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign feeds are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          feeds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedsRequest)

CampaignFeedOperation = _reflection.GeneratedProtocolMessageType('CampaignFeedOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNFEEDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign feed.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign feed.
      update:
          Update operation: The campaign feed is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed campaign
          feed is expected, in this format:  ``customers/{customer_id}/c
          ampaignFeeds/{campaign_id}_{feed_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignFeedOperation)
  ))
_sym_db.RegisterMessage(CampaignFeedOperation)

MutateCampaignFeedsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Response message for a campaign feed mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedsResponse)

MutateCampaignFeedResult = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """The result for the campaign feed mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedResult)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\030CampaignFeedServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNFEEDSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignFeedService',
  full_name='google.ads.googleads.v0.services.CampaignFeedService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=806,
  serialized_end=1223,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignFeed',
    full_name='google.ads.googleads.v0.services.CampaignFeedService.GetCampaignFeed',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNFEEDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0021\022//v0/{resource_name=customers/*/campaignFeeds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignFeeds',
    full_name='google.ads.googleads.v0.services.CampaignFeedService.MutateCampaignFeeds',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNFEEDSREQUEST,
    output_type=_MUTATECAMPAIGNFEEDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\"2/v0/customers/{customer_id=*}/campaignFeeds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNFEEDSERVICE)

DESCRIPTOR.services_by_name['CampaignFeedService'] = _CAMPAIGNFEEDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/feed_item_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import feed_item_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/feed_item_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/services/feed_item_service.proto\x12 google.ads.googleads.v0.services\x1a\x37google/ads/googleads_v0/proto/resources/feed_item.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"+\n\x12GetFeedItemRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"v\n\x16MutateFeedItemsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12G\n\noperations\x18\x02 \x03(\x0b\x32\x33.google.ads.googleads.v0.services.FeedItemOperation\"\xe1\x01\n\x11\x46\x65\x65\x64ItemOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12=\n\x06\x63reate\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v0.resources.FeedItemH\x00\x12=\n\x06update\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v0.resources.FeedItemH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"b\n\x17MutateFeedItemsResponse\x12G\n\x07results\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v0.services.MutateFeedItemResult\"-\n\x14MutateFeedItemResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xfd\x02\n\x0f\x46\x65\x65\x64ItemService\x12\xa5\x01\n\x0bGetFeedItem\x12\x34.google.ads.googleads.v0.services.GetFeedItemRequest\x1a+.google.ads.googleads.v0.resources.FeedItem\"3\x82\xd3\xe4\x93\x02-\x12+/v0/{resource_name=customers/*/feedItems/*}\x12\xc1\x01\n\x0fMutateFeedItems\x12\x38.google.ads.googleads.v0.services.MutateFeedItemsRequest\x1a\x39.google.ads.googleads.v0.services.MutateFeedItemsResponse\"9\x82\xd3\xe4\x93\x02\x33\"./v0/customers/{customer_id=*}/feedItems:mutate:\x01*B\xd4\x01\n$com.google.ads.googleads.v0.servicesB\x14\x46\x65\x65\x64ItemServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETFEEDITEMREQUEST = _descriptor.Descriptor(
  name='GetFeedItemRequest',
  full_name='google.ads.googleads.v0.services.GetFeedItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetFeedItemRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=264,
)


_MUTATEFEEDITEMSREQUEST = _descriptor.Descriptor(
  name='MutateFeedItemsRequest',
  full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=384,
)


_FEEDITEMOPERATION = _descriptor.Descriptor(
  name='FeedItemOperation',
  full_name='google.ads.googleads.v0.services.FeedItemOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.FeedItemOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.FeedItemOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.FeedItemOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.FeedItemOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.FeedItemOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=387,
  serialized_end=612,
)


_MUTATEFEEDITEMSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedItemsResponse',
  full_name='google.ads.googleads.v0.services.MutateFeedItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateFeedItemsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=712,
)


_MUTATEFEEDITEMRESULT = _descriptor.Descriptor(
  name='MutateFeedItemResult',
  full_name='google.ads.googleads.v0.services.MutateFeedItemResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateFeedItemResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=759,
)

_MUTATEFEEDITEMSREQUEST.fields_by_name['operations'].message_type = _FEEDITEMOPERATION
_FEEDITEMOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_FEEDITEMOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM
_FEEDITEMOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['create'])
_FEEDITEMOPERATION.fields_by_name['create'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['update'])
_FEEDITEMOPERATION.fields_by_name['update'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['remove'])
_FEEDITEMOPERATION.fields_by_name['remove'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_MUTATEFEEDITEMSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDITEMRESULT
DESCRIPTOR.message_types_by_name['GetFeedItemRequest'] = _GETFEEDITEMREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedItemsRequest'] = _MUTATEFEEDITEMSREQUEST
DESCRIPTOR.message_types_by_name['FeedItemOperation'] = _FEEDITEMOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedItemsResponse'] = _MUTATEFEEDITEMSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedItemResult'] = _MUTATEFEEDITEMRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedItemRequest = _reflection.GeneratedProtocolMessageType('GetFeedItemRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDITEMREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemService.GetFeedItem][google.ads.googleads.v0.services.FeedItemService.GetFeedItem].
  
  
  Attributes:
      resource_name:
          The resource name of the feed item to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetFeedItemRequest)
  ))
_sym_db.RegisterMessage(GetFeedItemRequest)

MutateFeedItemsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedItemsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemService.MutateFeedItems][google.ads.googleads.v0.services.FeedItemService.MutateFeedItems].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feed items are being modified.
      operations:
          The list of operations to perform on individual feed items.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedItemsRequest)

FeedItemOperation = _reflection.GeneratedProtocolMessageType('FeedItemOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an feed item.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed item.
      update:
          Update operation: The feed item is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed feed item is
          expected, in this format:
          ``customers/{customer_id}/feedItems/{feed_id}_{feed_item_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.FeedItemOperation)
  ))
_sym_db.RegisterMessage(FeedItemOperation)

MutateFeedItemsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedItemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Response message for an feed item mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedItemsResponse)

MutateFeedItemResult = _reflection.GeneratedProtocolMessageType('MutateFeedItemResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """The result for the feed item mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemResult)
  ))
_sym_db.RegisterMessage(MutateFeedItemResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\024FeedItemServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_FEEDITEMSERVICE = _descriptor.ServiceDescriptor(
  name='FeedItemService',
  full_name='google.ads.googleads.v0.services.FeedItemService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=762,
  serialized_end=1143,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeedItem',
    full_name='google.ads.googleads.v0.services.FeedItemService.GetFeedItem',
    index=0,
    containing_service=None,
    input_type=_GETFEEDITEMREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002-\022+/v0/{resource_name=customers/*/feedItems/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeedItems',
    full_name='google.ads.googleads.v0.services.FeedItemService.MutateFeedItems',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDITEMSREQUEST,
    output_type=_MUTATEFEEDITEMSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\"./v0/customers/{customer_id=*}/feedItems:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDITEMSERVICE)

DESCRIPTOR.services_by_name['FeedItemService'] = _FEEDITEMSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/mutate_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/mutate_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n7google/ads/googleads_v0/proto/errors/mutate_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xb1\x01\n\x0fMutateErrorEnum\"\x9d\x01\n\x0bMutateError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x16\n\x12RESOURCE_NOT_FOUND\x10\x03\x12!\n\x1dID_EXISTS_IN_MULTIPLE_MUTATES\x10\x07\x12\x1d\n\x19INCONSISTENT_FIELD_VALUES\x10\x08\x12\x16\n\x12MUTATE_NOT_ALLOWED\x10\tB\xc6\x01\n\"com.google.ads.googleads.v0.errorsB\x10MutateErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_MUTATEERRORENUM_MUTATEERROR = _descriptor.EnumDescriptor(
  name='MutateError',
  full_name='google.ads.googleads.v0.errors.MutateErrorEnum.MutateError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_NOT_FOUND', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ID_EXISTS_IN_MULTIPLE_MUTATES', index=3, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCONSISTENT_FIELD_VALUES', index=4, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTATE_NOT_ALLOWED', index=5, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=112,
  serialized_end=269,
)
_sym_db.RegisterEnumDescriptor(_MUTATEERRORENUM_MUTATEERROR)


_MUTATEERRORENUM = _descriptor.Descriptor(
  name='MutateErrorEnum',
  full_name='google.ads.googleads.v0.errors.MutateErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MUTATEERRORENUM_MUTATEERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=269,
)

_MUTATEERRORENUM_MUTATEERROR.containing_type = _MUTATEERRORENUM
DESCRIPTOR.message_types_by_name['MutateErrorEnum'] = _MUTATEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MutateErrorEnum = _reflection.GeneratedProtocolMessageType('MutateErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.mutate_error_pb2'
  ,
  __doc__ = """Container for enum describing possible mutate errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.MutateErrorEnum)
  ))
_sym_db.RegisterMessage(MutateErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\020MutateErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/customer_feed_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import customer_feed_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__feed__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/customer_feed_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nBgoogle/ads/googleads_v0/proto/services/customer_feed_service.proto\x12 google.ads.googleads.v0.services\x1a;google/ads/googleads_v0/proto/resources/customer_feed.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"/\n\x16GetCustomerFeedRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"~\n\x1aMutateCustomerFeedsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12K\n\noperations\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v0.services.CustomerFeedOperation\"\xed\x01\n\x15\x43ustomerFeedOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x41\n\x06\x63reate\x18\x01 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CustomerFeedH\x00\x12\x41\n\x06update\x18\x02 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CustomerFeedH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"j\n\x1bMutateCustomerFeedsResponse\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v0.services.MutateCustomerFeedResult\"1\n\x18MutateCustomerFeedResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xa1\x03\n\x13\x43ustomerFeedService\x12\xb5\x01\n\x0fGetCustomerFeed\x12\x38.google.ads.googleads.v0.services.GetCustomerFeedRequest\x1a/.google.ads.googleads.v0.resources.CustomerFeed\"7\x82\xd3\xe4\x93\x02\x31\x12//v0/{resource_name=customers/*/customerFeeds/*}\x12\xd1\x01\n\x13MutateCustomerFeeds\x12<.google.ads.googleads.v0.services.MutateCustomerFeedsRequest\x1a=.google.ads.googleads.v0.services.MutateCustomerFeedsResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v0/customers/{customer_id=*}/customerFeeds:mutate:\x01*B\xd8\x01\n$com.google.ads.googleads.v0.servicesB\x18\x43ustomerFeedServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__feed__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCUSTOMERFEEDREQUEST = _descriptor.Descriptor(
  name='GetCustomerFeedRequest',
  full_name='google.ads.googleads.v0.services.GetCustomerFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCustomerFeedRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=276,
)


_MUTATECUSTOMERFEEDSREQUEST = _descriptor.Descriptor(
  name='MutateCustomerFeedsRequest',
  full_name='google.ads.googleads.v0.services.MutateCustomerFeedsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCustomerFeedsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCustomerFeedsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=404,
)


_CUSTOMERFEEDOPERATION = _descriptor.Descriptor(
  name='CustomerFeedOperation',
  full_name='google.ads.googleads.v0.services.CustomerFeedOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CustomerFeedOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CustomerFeedOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CustomerFeedOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CustomerFeedOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CustomerFeedOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=407,
  serialized_end=644,
)


_MUTATECUSTOMERFEEDSRESPONSE = _descriptor.Descriptor(
  name='MutateCustomerFeedsResponse',
  full_name='google.ads.googleads.v0.services.MutateCustomerFeedsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCustomerFeedsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=752,
)


_MUTATECUSTOMERFEEDRESULT = _descriptor.Descriptor(
  name='MutateCustomerFeedResult',
  full_name='google.ads.googleads.v0.services.MutateCustomerFeedResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCustomerFeedResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=803,
)

_MUTATECUSTOMERFEEDSREQUEST.fields_by_name['operations'].message_type = _CUSTOMERFEEDOPERATION
_CUSTOMERFEEDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CUSTOMERFEEDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__feed__pb2._CUSTOMERFEED
_CUSTOMERFEEDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__feed__pb2._CUSTOMERFEED
_CUSTOMERFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERFEEDOPERATION.fields_by_name['create'])
_CUSTOMERFEEDOPERATION.fields_by_name['create'].containing_oneof = _CUSTOMERFEEDOPERATION.oneofs_by_name['operation']
_CUSTOMERFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERFEEDOPERATION.fields_by_name['update'])
_CUSTOMERFEEDOPERATION.fields_by_name['update'].containing_oneof = _CUSTOMERFEEDOPERATION.oneofs_by_name['operation']
_CUSTOMERFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERFEEDOPERATION.fields_by_name['remove'])
_CUSTOMERFEEDOPERATION.fields_by_name['remove'].containing_oneof = _CUSTOMERFEEDOPERATION.oneofs_by_name['operation']
_MUTATECUSTOMERFEEDSRESPONSE.fields_by_name['results'].message_type = _MUTATECUSTOMERFEEDRESULT
DESCRIPTOR.message_types_by_name['GetCustomerFeedRequest'] = _GETCUSTOMERFEEDREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomerFeedsRequest'] = _MUTATECUSTOMERFEEDSREQUEST
DESCRIPTOR.message_types_by_name['CustomerFeedOperation'] = _CUSTOMERFEEDOPERATION
DESCRIPTOR.message_types_by_name['MutateCustomerFeedsResponse'] = _MUTATECUSTOMERFEEDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerFeedResult'] = _MUTATECUSTOMERFEEDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerFeedRequest = _reflection.GeneratedProtocolMessageType('GetCustomerFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERFEEDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerFeedService.GetCustomerFeed][google.ads.googleads.v0.services.CustomerFeedService.GetCustomerFeed].
  
  
  Attributes:
      resource_name:
          The resource name of the customer feed to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCustomerFeedRequest)
  ))
_sym_db.RegisterMessage(GetCustomerFeedRequest)

MutateCustomerFeedsRequest = _reflection.GeneratedProtocolMessageType('MutateCustomerFeedsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERFEEDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerFeedService.MutateCustomerFeeds][google.ads.googleads.v0.services.CustomerFeedService.MutateCustomerFeeds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose customer feeds are being
          modified.
      operations:
          The list of operations to perform on individual customer
          feeds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCustomerFeedsRequest)
  ))
_sym_db.RegisterMessage(MutateCustomerFeedsRequest)

CustomerFeedOperation = _reflection.GeneratedProtocolMessageType('CustomerFeedOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERFEEDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_feed_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a customer feed.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          customer feed.
      update:
          Update operation: The customer feed is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed customer
          feed is expected, in this format:
          ``customers/{customer_id}/customerFeeds/{feed_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CustomerFeedOperation)
  ))
_sym_db.RegisterMessage(CustomerFeedOperation)

MutateCustomerFeedsResponse = _reflection.GeneratedProtocolMessageType('MutateCustomerFeedsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERFEEDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_feed_service_pb2'
  ,
  __doc__ = """Response message for a customer feed mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCustomerFeedsResponse)
  ))
_sym_db.RegisterMessage(MutateCustomerFeedsResponse)

MutateCustomerFeedResult = _reflection.GeneratedProtocolMessageType('MutateCustomerFeedResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERFEEDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_feed_service_pb2'
  ,
  __doc__ = """The result for the customer feed mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCustomerFeedResult)
  ))
_sym_db.RegisterMessage(MutateCustomerFeedResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\030CustomerFeedServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CUSTOMERFEEDSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerFeedService',
  full_name='google.ads.googleads.v0.services.CustomerFeedService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=806,
  serialized_end=1223,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomerFeed',
    full_name='google.ads.googleads.v0.services.CustomerFeedService.GetCustomerFeed',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERFEEDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__feed__pb2._CUSTOMERFEED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0021\022//v0/{resource_name=customers/*/customerFeeds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomerFeeds',
    full_name='google.ads.googleads.v0.services.CustomerFeedService.MutateCustomerFeeds',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMERFEEDSREQUEST,
    output_type=_MUTATECUSTOMERFEEDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\"2/v0/customers/{customer_id=*}/customerFeeds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERFEEDSERVICE)

DESCRIPTOR.services_by_name['CustomerFeedService'] = _CUSTOMERFEEDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/attribution_model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/attribution_model.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n;google/ads/googleads_v0/proto/enums/attribution_model.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xc6\x02\n\x14\x41ttributionModelEnum\"\xad\x02\n\x10\x41ttributionModel\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x64\x12\x19\n\x15GOOGLE_ADS_LAST_CLICK\x10\x65\x12)\n%GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK\x10\x66\x12$\n GOOGLE_SEARCH_ATTRIBUTION_LINEAR\x10g\x12(\n$GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY\x10h\x12,\n(GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED\x10i\x12)\n%GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN\x10jB\xc6\x01\n!com.google.ads.googleads.v0.enumsB\x15\x41ttributionModelProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_ATTRIBUTIONMODELENUM_ATTRIBUTIONMODEL = _descriptor.EnumDescriptor(
  name='AttributionModel',
  full_name='google.ads.googleads.v0.enums.AttributionModelEnum.AttributionModel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=2, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ADS_LAST_CLICK', index=3, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK', index=4, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_SEARCH_ATTRIBUTION_LINEAR', index=5, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY', index=6, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED', index=7, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN', index=8, number=106,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=120,
  serialized_end=421,
)
_sym_db.RegisterEnumDescriptor(_ATTRIBUTIONMODELENUM_ATTRIBUTIONMODEL)


_ATTRIBUTIONMODELENUM = _descriptor.Descriptor(
  name='AttributionModelEnum',
  full_name='google.ads.googleads.v0.enums.AttributionModelEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ATTRIBUTIONMODELENUM_ATTRIBUTIONMODEL,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=421,
)

_ATTRIBUTIONMODELENUM_ATTRIBUTIONMODEL.containing_type = _ATTRIBUTIONMODELENUM
DESCRIPTOR.message_types_by_name['AttributionModelEnum'] = _ATTRIBUTIONMODELENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AttributionModelEnum = _reflection.GeneratedProtocolMessageType('AttributionModelEnum', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTIONMODELENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.attribution_model_pb2'
  ,
  __doc__ = """Container for enum representing the attribution model that describes how
  to distribute credit for a particular conversion across potentially many
  prior interactions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.AttributionModelEnum)
  ))
_sym_db.RegisterMessage(AttributionModelEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\025AttributionModelProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/feed_mapping_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import feed_mapping_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/feed_mapping_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nAgoogle/ads/googleads_v0/proto/services/feed_mapping_service.proto\x12 google.ads.googleads.v0.services\x1a:google/ads/googleads_v0/proto/resources/feed_mapping.proto\x1a\x1cgoogle/api/annotations.proto\".\n\x15GetFeedMappingRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"|\n\x19MutateFeedMappingsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12J\n\noperations\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v0.services.FeedMappingOperation\"w\n\x14\x46\x65\x65\x64MappingOperation\x12@\n\x06\x63reate\x18\x01 \x01(\x0b\x32..google.ads.googleads.v0.resources.FeedMappingH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"h\n\x1aMutateFeedMappingsResponse\x12J\n\x07results\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v0.services.MutateFeedMappingResult\"0\n\x17MutateFeedMappingResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x98\x03\n\x12\x46\x65\x65\x64MappingService\x12\xb1\x01\n\x0eGetFeedMapping\x12\x37.google.ads.googleads.v0.services.GetFeedMappingRequest\x1a..google.ads.googleads.v0.resources.FeedMapping\"6\x82\xd3\xe4\x93\x02\x30\x12./v0/{resource_name=customers/*/feedMappings/*}\x12\xcd\x01\n\x12MutateFeedMappings\x12;.google.ads.googleads.v0.services.MutateFeedMappingsRequest\x1a<.google.ads.googleads.v0.services.MutateFeedMappingsResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/v0/customers/{customer_id=*}/feedMappings:mutate:\x01*B\xd7\x01\n$com.google.ads.googleads.v0.servicesB\x17\x46\x65\x65\x64MappingServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETFEEDMAPPINGREQUEST = _descriptor.Descriptor(
  name='GetFeedMappingRequest',
  full_name='google.ads.googleads.v0.services.GetFeedMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetFeedMappingRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=239,
)


_MUTATEFEEDMAPPINGSREQUEST = _descriptor.Descriptor(
  name='MutateFeedMappingsRequest',
  full_name='google.ads.googleads.v0.services.MutateFeedMappingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateFeedMappingsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateFeedMappingsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=365,
)


_FEEDMAPPINGOPERATION = _descriptor.Descriptor(
  name='FeedMappingOperation',
  full_name='google.ads.googleads.v0.services.FeedMappingOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.FeedMappingOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.FeedMappingOperation.remove', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.FeedMappingOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=367,
  serialized_end=486,
)


_MUTATEFEEDMAPPINGSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedMappingsResponse',
  full_name='google.ads.googleads.v0.services.MutateFeedMappingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateFeedMappingsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=592,
)


_MUTATEFEEDMAPPINGRESULT = _descriptor.Descriptor(
  name='MutateFeedMappingResult',
  full_name='google.ads.googleads.v0.services.MutateFeedMappingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateFeedMappingResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=642,
)

_MUTATEFEEDMAPPINGSREQUEST.fields_by_name['operations'].message_type = _FEEDMAPPINGOPERATION
_FEEDMAPPINGOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2._FEEDMAPPING
_FEEDMAPPINGOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDMAPPINGOPERATION.fields_by_name['create'])
_FEEDMAPPINGOPERATION.fields_by_name['create'].containing_oneof = _FEEDMAPPINGOPERATION.oneofs_by_name['operation']
_FEEDMAPPINGOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDMAPPINGOPERATION.fields_by_name['remove'])
_FEEDMAPPINGOPERATION.fields_by_name['remove'].containing_oneof = _FEEDMAPPINGOPERATION.oneofs_by_name['operation']
_MUTATEFEEDMAPPINGSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDMAPPINGRESULT
DESCRIPTOR.message_types_by_name['GetFeedMappingRequest'] = _GETFEEDMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedMappingsRequest'] = _MUTATEFEEDMAPPINGSREQUEST
DESCRIPTOR.message_types_by_name['FeedMappingOperation'] = _FEEDMAPPINGOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedMappingsResponse'] = _MUTATEFEEDMAPPINGSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedMappingResult'] = _MUTATEFEEDMAPPINGRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedMappingRequest = _reflection.GeneratedProtocolMessageType('GetFeedMappingRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDMAPPINGREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedMappingService.GetFeedMapping][google.ads.googleads.v0.services.FeedMappingService.GetFeedMapping].
  
  
  Attributes:
      resource_name:
          The resource name of the feed mapping to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetFeedMappingRequest)
  ))
_sym_db.RegisterMessage(GetFeedMappingRequest)

MutateFeedMappingsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedMappingsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedMappingService.MutateFeedMappings][google.ads.googleads.v0.services.FeedMappingService.MutateFeedMappings].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feed mappings are being modified.
      operations:
          The list of operations to perform on individual feed mappings.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedMappingsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedMappingsRequest)

FeedMappingOperation = _reflection.GeneratedProtocolMessageType('FeedMappingOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPINGOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on a feed mapping.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed mapping.
      remove:
          Remove operation: A resource name for the removed feed mapping
          is expected, in this format:  ``customers/{customer_id}/feedMa
          ppings/{feed_id}_{feed_mapping_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.FeedMappingOperation)
  ))
_sym_db.RegisterMessage(FeedMappingOperation)

MutateFeedMappingsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedMappingsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Response message for a feed mapping mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedMappingsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedMappingsResponse)

MutateFeedMappingResult = _reflection.GeneratedProtocolMessageType('MutateFeedMappingResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """The result for the feed mapping mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedMappingResult)
  ))
_sym_db.RegisterMessage(MutateFeedMappingResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\027FeedMappingServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_FEEDMAPPINGSERVICE = _descriptor.ServiceDescriptor(
  name='FeedMappingService',
  full_name='google.ads.googleads.v0.services.FeedMappingService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=645,
  serialized_end=1053,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeedMapping',
    full_name='google.ads.googleads.v0.services.FeedMappingService.GetFeedMapping',
    index=0,
    containing_service=None,
    input_type=_GETFEEDMAPPINGREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2._FEEDMAPPING,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0020\022./v0/{resource_name=customers/*/feedMappings/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeedMappings',
    full_name='google.ads.googleads.v0.services.FeedMappingService.MutateFeedMappings',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDMAPPINGSREQUEST,
    output_type=_MUTATEFEEDMAPPINGSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0026\"1/v0/customers/{customer_id=*}/feedMappings:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDMAPPINGSERVICE)

DESCRIPTOR.services_by_name['FeedMappingService'] = _FEEDMAPPINGSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/customer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/customer.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n6google/ads/googleads_v0/proto/resources/customer.proto\x12!google.ads.googleads.v0.resources\x1a\x1egoogle/protobuf/wrappers.proto\"\xa8\x04\n\x08\x43ustomer\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10\x64\x65scriptive_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rcurrency_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x66inal_url_suffix\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x14\x61uto_tagging_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12has_partners_badge\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12W\n\x16\x63\x61ll_reporting_setting\x18\n \x01(\x0b\x32\x37.google.ads.googleads.v0.resources.CallReportingSetting\"\xd7\x01\n\x14\x43\x61llReportingSetting\x12:\n\x16\x63\x61ll_reporting_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n!call_conversion_reporting_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16\x63\x61ll_conversion_action\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xd2\x01\n%com.google.ads.googleads.v0.resourcesB\rCustomerProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_CUSTOMER = _descriptor.Descriptor(
  name='Customer',
  full_name='google.ads.googleads.v0.resources.Customer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.Customer.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.Customer.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptive_name', full_name='google.ads.googleads.v0.resources.Customer.descriptive_name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v0.resources.Customer.currency_code', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='google.ads.googleads.v0.resources.Customer.time_zone', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v0.resources.Customer.tracking_url_template', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v0.resources.Customer.final_url_suffix', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_tagging_enabled', full_name='google.ads.googleads.v0.resources.Customer.auto_tagging_enabled', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_partners_badge', full_name='google.ads.googleads.v0.resources.Customer.has_partners_badge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_reporting_setting', full_name='google.ads.googleads.v0.resources.Customer.call_reporting_setting', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=678,
)


_CALLREPORTINGSETTING = _descriptor.Descriptor(
  name='CallReportingSetting',
  full_name='google.ads.googleads.v0.resources.CallReportingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_reporting_enabled', full_name='google.ads.googleads.v0.resources.CallReportingSetting.call_reporting_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_reporting_enabled', full_name='google.ads.googleads.v0.resources.CallReportingSetting.call_conversion_reporting_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_action', full_name='google.ads.googleads.v0.resources.CallReportingSetting.call_conversion_action', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=896,
)

_CUSTOMER.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CUSTOMER.fields_by_name['descriptive_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMER.fields_by_name['auto_tagging_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['has_partners_badge'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CUSTOMER.fields_by_name['call_reporting_setting'].message_type = _CALLREPORTINGSETTING
_CALLREPORTINGSETTING.fields_by_name['call_reporting_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLREPORTINGSETTING.fields_by_name['call_conversion_reporting_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLREPORTINGSETTING.fields_by_name['call_conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Customer'] = _CUSTOMER
DESCRIPTOR.message_types_by_name['CallReportingSetting'] = _CALLREPORTINGSETTING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Customer = _reflection.GeneratedProtocolMessageType('Customer', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMER,
  __module__ = 'google.ads.google_ads.v0.proto.resources.customer_pb2'
  ,
  __doc__ = """A customer.
  
  
  Attributes:
      resource_name:
          The resource name of the customer. Customer resource names
          have the form:  ``customers/{customer_id}``
      id:
          The ID of the customer.
      descriptive_name:
          Optional, non-unique descriptive name of the customer.
      currency_code:
          The currency in which the account operates. A subset of the
          currency codes from the ISO 4217 standard is supported.
      time_zone:
          The local timezone ID of the customer.
      tracking_url_template:
          The URL template for constructing a tracking URL out of
          parameters.
      final_url_suffix:
          The URL template for appending params to the final URL
      auto_tagging_enabled:
          Whether auto-tagging is enabled for the customer.
      has_partners_badge:
          Whether the Customer has a Partners program badge. If the
          Customer is not associated with the Partners program, this
          will be false. For more information, see
          https://support.google.com/partners/answer/3125774.
      call_reporting_setting:
          Call reporting setting for a customer.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.Customer)
  ))
_sym_db.RegisterMessage(Customer)

CallReportingSetting = _reflection.GeneratedProtocolMessageType('CallReportingSetting', (_message.Message,), dict(
  DESCRIPTOR = _CALLREPORTINGSETTING,
  __module__ = 'google.ads.google_ads.v0.proto.resources.customer_pb2'
  ,
  __doc__ = """Call reporting setting for a customer.
  
  
  Attributes:
      call_reporting_enabled:
          Enable reporting of phone call events by redirecting them via
          Google System.
      call_conversion_reporting_enabled:
          Whether to enable call conversion reporting.
      call_conversion_action:
          Customer-level call conversion action to attribute a call
          conversion to. If not set a default conversion action is used.
          Only in effect when call\_conversion\_reporting\_enabled is
          set to true.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.CallReportingSetting)
  ))
_sym_db.RegisterMessage(CallReportingSetting)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\rCustomerProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)
